package cmd

import (
	"fmt"
	"log"
	"os"

	"github.com/knipferrc/fm/internal/config"
	"github.com/knipferrc/fm/internal/tui"

	tea "github.com/charmbracelet/bubbletea"
	"github.com/muesli/coral"
)

var rootCmd = &coral.Command{
	Use:     "fm",
	Short:   "FM is a simple, configurable, and fun to use file manager",
	Version: "0.13.2",
	Args:    coral.MaximumNArgs(1),
	Run: func(cmd *coral.Command, args []string) {
		startDir := cmd.Flags().Lookup("start-dir")
		selectionPath := cmd.Flags().Lookup("selection-path")

		config.LoadConfig(startDir, selectionPath)
		cfg := config.GetConfig()

		m := tui.New()
		var opts []tea.ProgramOption

		// Always append alt screen program option.
		opts = append(opts, tea.WithAltScreen())

		// If mousewheel is enabled, append it to the program options.
		if cfg.Settings.EnableMouseWheel {
			opts = append(opts, tea.WithMouseAllMotion())
		}

		// Initialize and start app.
		p := tea.NewProgram(m, opts...)
		if err := p.Start(); err != nil {
			log.Fatal("Failed to start fm", err)
		}
	},
}

// Execute runs the root command and starts the application.
func Execute() {
	rootCmd.AddCommand(updateCmd)
	rootCmd.PersistentFlags().String("selection-path", "", "Path to write to file on open.")
	rootCmd.PersistentFlags().String("start-dir", "", "Starting directory for FM")

	if err := rootCmd.Execute(); err != nil {
		fmt.Fprintln(os.Stderr, err)
		os.Exit(1)
	}
}
